pub enum WatchError {
Git(GitError),
Watch {
path: PathBuf,
source: Error,
},
Stopped,
}Expand description
A failure while starting, watching, or loading for a crate::RepositoryWatcher.
Variants
Git(GitError)
Watch
The platform watcher could not be created or could not observe a path.
Fields
Stopped
The watcher task is no longer running.